@@ -181,25 +181,6 @@ ALL_ROUTES = [
     ('loadbal:service-edit', 'SoftLayer.CLI.loadbal.service_edit:cli'),
     ('loadbal:service-toggle', 'SoftLayer.CLI.loadbal.service_toggle:cli'),
 
-    ('messaging', 'SoftLayer.CLI.mq'),
-    ('messaging:accounts-list', 'SoftLayer.CLI.mq.accounts_list:cli'),
-    ('messaging:endpoints-list', 'SoftLayer.CLI.mq.endpoints_list:cli'),
-    ('messaging:ping', 'SoftLayer.CLI.mq.ping:cli'),
-    ('messaging:queue-add', 'SoftLayer.CLI.mq.queue_add:cli'),
-    ('messaging:queue-detail', 'SoftLayer.CLI.mq.queue_detail:cli'),
-    ('messaging:queue-edit', 'SoftLayer.CLI.mq.queue_edit:cli'),
-    ('messaging:queue-list', 'SoftLayer.CLI.mq.queue_list:cli'),
-    ('messaging:queue-pop', 'SoftLayer.CLI.mq.queue_pop:cli'),
-    ('messaging:queue-push', 'SoftLayer.CLI.mq.queue_push:cli'),
-    ('messaging:queue-remove', 'SoftLayer.CLI.mq.queue_remove:cli'),
-    ('messaging:topic-add', 'SoftLayer.CLI.mq.topic_add:cli'),
-    ('messaging:topic-detail', 'SoftLayer.CLI.mq.topic_detail:cli'),
-    ('messaging:topic-list', 'SoftLayer.CLI.mq.topic_list:cli'),
-    ('messaging:topic-push', 'SoftLayer.CLI.mq.topic_push:cli'),
-    ('messaging:topic-remove', 'SoftLayer.CLI.mq.topic_remove:cli'),
-    ('messaging:topic-subscribe', 'SoftLayer.CLI.mq.topic_subscribe:cli'),
-    ('messaging:topic-unsubscribe', 'SoftLayer.CLI.mq.topic_unsubscribe:cli'),
-
     ('metadata', 'SoftLayer.CLI.metadata:cli'),
 
     ('nas', 'SoftLayer.CLI.nas'),
@@ -240,6 +221,7 @@ ALL_ROUTES = [
     ('hardware:reload', 'SoftLayer.CLI.hardware.reload:cli'),
     ('hardware:credentials', 'SoftLayer.CLI.hardware.credentials:cli'),
     ('hardware:update-firmware', 'SoftLayer.CLI.hardware.update_firmware:cli'),
+    ('hardware:reflash-firmware', 'SoftLayer.CLI.hardware.reflash_firmware:cli'),
     ('hardware:rescue', 'SoftLayer.CLI.hardware.power:rescue'),
     ('hardware:ready', 'SoftLayer.CLI.hardware.ready:cli'),
     ('hardware:toggle-ipmi', 'SoftLayer.CLI.hardware.toggle_ipmi:cli'),
