@@ -316,9 +316,14 @@ getSubnets = [
     {
         'id': '100',
         'networkIdentifier': '10.0.0.1',
+        'cidr': '/24',
+        'networkVlanId': 123,
         'datacenter': {'name': 'dal00'},
         'version': 4,
-        'subnetType': 'PRIMARY'
+        'subnetType': 'PRIMARY',
+        'ipAddressCount': 10,
+        'virtualGuests': [],
+        'hardware': []
     }]
 
 getSshKeys = [{'id': '100', 'label': 'Test 1'},
@@ -586,7 +591,7 @@ getReservedCapacityGroups = [
         'modifyDate': '',
         'name': 'test-capacity',
         'availableInstanceCount': 1,
-        'instanceCount': 2,
+        'instanceCount': 3,
         'occupiedInstanceCount': 1,
         'backendRouter': {
             'accountId': 1,
@@ -633,7 +638,27 @@ getReservedCapacityGroups = [
                     'description': 'B1.1x2 (1 Year Term)',
                     'hourlyRecurringFee': '.032'
                 }
+            },
+            {
+                'id': 3519
             }
         ]
     }
 ]
+
+
+getPlacementGroups = [{
+    "createDate": "2019-01-18T16:08:44-06:00",
+    "id": 12345,
+    "name": "test01",
+    "guestCount": 0,
+    "backendRouter": {
+        "hostname": "bcr01a.mex01",
+        "id": 329266
+    },
+    "rule": {
+        "id": 1,
+        "keyName": "SPREAD",
+        "name": "SPREAD"
+    }
+}]
