@@ -34,7 +34,7 @@ __all__ = [
 ]
 
 REST_SPECIAL_METHODS = {
-    'deleteObject': 'DELETE',
+    # 'deleteObject': 'DELETE',
     'createObject': 'POST',
     'createObjects': 'POST',
     'editObject': 'PUT',
@@ -120,21 +120,31 @@ class Request(object):
         #: Exception any exceptions that got caught
         self.exception = None
 
+    def __repr__(self):
+        """Prints out what this call is all about"""
+        pretty_mask = utils.clean_string(self.mask)
+        pretty_filter = self.filter
+        param_string = "id={id}, mask='{mask}', filter='{filter}', args={args}, limit={limit}, offset={offset}".format(
+            id=self.identifier, mask=pretty_mask, filter=pretty_filter,
+            args=self.args, limit=self.limit, offset=self.offset)
+        return "{service}::{method}({params})".format(
+            service=self.service, method=self.method, params=param_string)
+
 
 class SoftLayerListResult(list):
     """A SoftLayer API list result."""
 
-    def __init__(self, items, total_count):
+    def __init__(self, items=None, total_count=0):
 
         #: total count of items that exist on the server. This is useful when
         #: paginating through a large list of objects.
         self.total_count = total_count
-
         super(SoftLayerListResult, self).__init__(items)
 
 
 class XmlRpcTransport(object):
     """XML-RPC transport."""
+
     def __init__(self, endpoint_url=None, timeout=None, proxy=None, user_agent=None, verify=True):
 
         self.endpoint_url = (endpoint_url or consts.API_PUBLIC_ENDPOINT).rstrip('/')
@@ -369,7 +379,15 @@ class RestTransport(object):
             request.url = resp.url
 
             resp.raise_for_status()
-            result = json.loads(resp.text)
+
+            if resp.text != "":
+                try:
+                    result = json.loads(resp.text)
+                except ValueError as json_ex:
+                    raise exceptions.SoftLayerAPIError(resp.status_code, str(json_ex))
+            else:
+                raise exceptions.SoftLayerAPIError(resp.status_code, "Empty response.")
+
             request.result = result
 
             if isinstance(result, list):
@@ -378,8 +396,15 @@ class RestTransport(object):
             else:
                 return result
         except requests.HTTPError as ex:
-            message = json.loads(ex.response.text)['error']
-            request.url = ex.response.url
+            try:
+                message = json.loads(ex.response.text)['error']
+                request.url = ex.response.url
+            except ValueError as json_ex:
+                if ex.response.text == "":
+                    raise exceptions.SoftLayerAPIError(resp.status_code, "Empty response.")
+                else:
+                    raise exceptions.SoftLayerAPIError(resp.status_code, str(json_ex))
+
             raise exceptions.SoftLayerAPIError(ex.response.status_code, message)
         except requests.RequestException as ex:
             raise exceptions.TransportError(0, str(ex))
@@ -433,13 +458,14 @@ class DebugTransport(object):
         self.requests.append(call)
 
         if call.exception is not None:
+            LOGGER.debug(self.print_reproduceable(call))
             raise call.exception
 
         return call.result
 
     def pre_transport_log(self, call):
         """Prints a warning before calling the API """
-        output = "Calling: {}::{}(id={})".format(call.service, call.method, call.identifier)
+        output = "Calling: {})".format(call)
         LOGGER.warning(output)
 
     def post_transport_log(self, call):
@@ -490,6 +516,7 @@ class TimingTransport(object):
 
 class FixtureTransport(object):
     """Implements a transport which returns fixtures."""
+
     def __call__(self, call):
         """Load fixture from the default fixture path."""
         try:
